summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabel/kbabelview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /kbabel/kbabel/kbabelview.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/kbabel/kbabelview.h')
-rw-r--r--kbabel/kbabel/kbabelview.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kbabel/kbabel/kbabelview.h b/kbabel/kbabel/kbabelview.h
index be492548..8fecb9f0 100644
--- a/kbabel/kbabel/kbabelview.h
+++ b/kbabel/kbabel/kbabelview.h
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -93,12 +93,13 @@ class TagListView;
class KBabelView : public TQWidget, public KBabel::CatalogView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor
* @param buildLeds flag, if status leds should be created in editor
*/
- KBabelView(KBCatalog* catalog,KBabelMW *parent, KBabel::Project::Ptr project);
+ KBabelView(KBCatalog* catalog,KBabelMW *tqparent, KBabel::Project::Ptr project);
/**
* Destructor
@@ -202,7 +203,7 @@ public slots:
/** opens a filedialog and asks for an url */
void open();
- void open(const KURL& url, const TQString & package=TQString::null, bool checkModified=true, bool newView=false);
+ void open(const KURL& url, const TQString & package=TQString(), bool checkModified=true, bool newView=false);
void setFilePackage();
void revertToSaved();
@@ -216,10 +217,10 @@ public slots:
void textPaste();
bool findNext();
bool findPrev();
- void find();
+ void tqfind();
void findInFile(TQCString fileSource, KBabel::FindOptions options);
void replaceInFile(TQCString fileSource, KBabel::ReplaceOptions options);
- void replace();
+ void tqreplace();
void selectAll();
void deselectAll();
void clear();
@@ -267,7 +268,7 @@ public slots:
void skipToTagFromTool(int index);
void wordCount();
- void removeFuzzyStatus();
+ void removeFuzzytqStatus();
/** opens the header editor for the po-file */
void editHeader();
@@ -450,7 +451,7 @@ protected slots:
private slots:
void msgstrPluralFormChanged (uint index);
- void autoRemoveFuzzyStatus();
+ void autoRemoveFuzzytqStatus();
/** connected to the catalog. it is called when a new file is opened*/
void newFileOpened(bool readOnly);
@@ -469,13 +470,13 @@ private slots:
*/
void replaceNext();
/**
* called from a signal from ReplaceDialog to replace
* all without asking anymore.
*/
void replaceAll();
/**
* called from a signal from ReplaceDialog to go to next
- * string to replace
+ * string to tqreplace
*/
void findNextReplace();
@@ -469,13 +470,13 @@ private slots:
void replaceNext();
/**
- * called from a signal from ReplaceDialog to replace
+ * called from a signal from ReplaceDialog to tqreplace
* all without asking anymore.
*/